AppApiGroup class final

Um bloco temático de endpoints dentro do contexto de uma tela — "CRUD de dispositivos", "Associação de chip".

Annotations

Constructors

AppApiGroup({required String title, required List<AppApiEndpoint> endpoints, String? description})
Cria um AppApiGroup.
const

Properties

description → String?
Linha de contexto opcional.
final
endpoints → List<AppApiEndpoint>
Endpoints do bloco, na ordem de leitura.
final
hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
title → String
Título do bloco.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited