AppApiParamLocation enum

Onde um parâmetro viaja na requisição.

Inheritance
Available extensions

Values

path → const AppApiParamLocation

Segmento do path (/devices/{id}).

query → const AppApiParamLocation

Query string (?page=1).

Cabeçalho HTTP.

body → const AppApiParamLocation

Corpo da requisição.

formData → const AppApiParamLocation

Campo de formulário (multipart/urlencoded).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
label String
Rótulo curto exibido na tabela de parâmetros.
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

tryParse(String value) AppApiParamLocation?
Converte a chave in: do OpenAPI no enum. null quando desconhecida.

Constants

values → const List<AppApiParamLocation>
A constant List of the values in this enum, in order of their declaration.