AppCartesianChartSeries class final

Constructors

AppCartesianChartSeries({required String id, required String label, required List<AppCartesianChartPoint> points, Color? color, AppLineChartCurveStyle curveStyle = AppLineChartCurveStyle.straight, Gradient? gradient, bool isDashed = false, bool showPoints = true})
const

Properties

color Color?
final
curveStyle AppLineChartCurveStyle
final
gradient Gradient?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
isDashed bool
final
label String
final
points List<AppCartesianChartPoint>
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showPoints bool
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited