AppCheckmarkPainter class

Desenha um "tique" (✓) com o traço revelado progressivamente.

O caminho é traçado em coordenadas relativas ao Size recebido, então o mesmo painter serve a um checkbox de 24 px e a um ícone de 16 px. Com progress < 1 apenas essa fração do comprimento do traço é desenhada — é o que permite animar o desenho em vez de aparecer pronto.

É um CustomPainter, não um ícone de rede: usar isto num estado de confirmação evita que uma falha de download vire um erro visual bem no momento em que o usuário precisa da confirmação.

AppValueBuilder(
  value: checked ? 1.0 : 0.0,
  builder: (context, t, _) => CustomPaint(
    painter: AppCheckmarkPainter(color: colors.indicator, progress: t),
  ),
)
Inheritance

Constructors

AppCheckmarkPainter({required Color color, double progress = 1.0, double strokeWidth = 2.0})
Cria um AppCheckmarkPainter.

Properties

color Color
Cor do traço.
final
hashCode int
The hash code for this object.
no setterinherited
progress double
Fração do traço desenhada (0–1).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticsBuilder SemanticsBuilderCallback?
Returns a function that builds semantic information for the picture drawn by this painter.
no setterinherited
strokeWidth double
Espessura do traço.
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be notified when it is time to repaint.
inherited
hitTest(Offset position) bool?
Called whenever a hit test is being performed on an object that is using this custom paint delegate.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size) → void
Called whenever the object needs to paint. The given Canvas has its coordinate space configured such that the origin is at the top left of the box. The area of the box is the size of the size argument.
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies when it is time to repaint.
inherited
shouldRebuildSemantics(covariant CustomPainter oldDelegate) bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
inherited
shouldRepaint(covariant AppCheckmarkPainter oldDelegate) bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited