AppEntityIntegrationDirection enum

Sentido em que uma integração externa troca dados com a entidade.

Inheritance
Available extensions

Values

inbound → const AppEntityIntegrationDirection

O sistema externo envia dados para a Tracked.

outbound → const AppEntityIntegrationDirection

A Tracked envia dados para o sistema externo.

bidirectional → const AppEntityIntegrationDirection

Os dois sentidos.

Properties

badgeColor AppBadgeColor
Papel de cor da pílula.
no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
label String
Rótulo curto exibido na pílula.
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AppEntityIntegrationDirection>
A constant List of the values in this enum, in order of their declaration.