AppEntityRelationKind enum

Cardinalidade de uma relação entre entidades.

Inheritance
Available extensions

Values

oneToOne → const AppEntityRelationKind

Um para um.

oneToMany → const AppEntityRelationKind

Um para muitos — esta entidade é o lado "um".

manyToOne → const AppEntityRelationKind

Muitos para um — esta entidade é o lado "muitos".

manyToMany → const AppEntityRelationKind

Muitos para muitos (normalmente por uma tabela de associação).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
label String
Rótulo curto exibido na pílula (1 → N).
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AppEntityRelationKind>
A constant List of the values in this enum, in order of their declaration.