AppListTile class final

Linha de lista do design system, em dois estilos (AppListTileStyle) e com variações ortogonais via construtores nomeados: navegação (chevron), checkbox, switch (toggle) e badge — todas com leading e subtitle opcionais e reorderIndex (draggable). Agrupe várias com AppListTileGroup.

Sobre um scaffold com hover/press/foco (FlocksInteraction), cores 100% do tema, raio/animação globais. Para seleção única use AppListTileRadio.

AppListTile.navigation(
  leading: AppIcon(AppIconToken.support),
  title: 'Suporte',
  onTap: openSupport,
)
Inheritance

Constructors

AppListTile({required String title, bool danger = false, String? subtitle, Widget? leading, Widget? trailing, VoidCallback? onTap, AppListTileStyle style = AppListTileStyle.grouped, bool enabled = true, int? reorderIndex, bool reorderEnabled = true, String? semanticLabel, Key? key})
Tile genérico: trailing custom (badge, ação…) e onTap opcionais.
const
AppListTile.badge({required String title, required String badge, AppBadgeColor badgeColor = AppBadgeColor.neutral, bool danger = false, VoidCallback? onTap, String? subtitle, Widget? leading, AppListTileStyle style = AppListTileStyle.grouped, bool enabled = true, int? reorderIndex, bool reorderEnabled = true, String? semanticLabel, Key? key})
Tile com badge no trailing (+ onTap opcional).
const
AppListTile.checkbox({required String title, required bool value, ValueChanged<bool>? onChanged, bool danger = false, String? subtitle, Widget? leading, AppListTileStyle style = AppListTileStyle.grouped, bool enabled = true, int? reorderIndex, bool reorderEnabled = true, String? semanticLabel, Key? key})
Tile com checkbox: tocar a linha alterna (value/onChanged).
const
AppListTile.navigation({required String title, required VoidCallback? onTap, bool danger = false, String? subtitle, Widget? leading, AppListTileStyle style = AppListTileStyle.grouped, bool enabled = true, int? reorderIndex, bool reorderEnabled = true, String? semanticLabel, Key? key})
Tile de navegação: trailing = chevron; tocar navega (onTap).
const
AppListTile.toggle({required String title, required bool value, ValueChanged<bool>? onChanged, bool danger = false, String? subtitle, Widget? leading, AppListTileStyle style = AppListTileStyle.grouped, bool enabled = true, int? reorderIndex, bool reorderEnabled = true, String? semanticLabel, Key? key})
Tile com switch (toggle): tocar a linha alterna.
const

Properties

danger → bool
Aplica o papel semântico destrutivo ao conteúdo do tile.
final
enabled → bool
Se está habilitado.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leading → Widget?
Leading (ícone/avatar), opcional.
final
onTap → VoidCallback?
Ação de toque (genérico/navigation/badge).
final
reorderEnabled → bool
Se o reordenamento está ativo.
final
reorderIndex → int?
Draggable: índice de reordenamento (adiciona drag handle).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel → String?
Rótulo de acessibilidade (default: title).
final
style → AppListTileStyle
Estilo do container quando avulso.
final
subtitle → String?
Subtítulo (muted, opcional).
final
title → String
Título (forte).
final
trailing → Widget?
Trailing custom (só no construtor genérico).
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited