AppListTileRadio<T> class final

Linha de lista com um radio (seleção única em grupo). Tocar a linha seleciona o value. Genérico AppListTileRadio<T> — classe própria porque um construtor nomeado não pode introduzir <T> (como RadioListTile<T>).

Mesmos estilos/variações do AppListTile (leading/subtitle/draggable); agrupe com AppListTileGroup.

AppListTileRadio<String>(
  title: 'Polo Track 01',
  value: 'a', groupValue: selected, onChanged: choose,
)
Inheritance

Constructors

AppListTileRadio({required String title, required T value, required T? groupValue, ValueChanged<T?>? onChanged, String? subtitle, Widget? leading, AppListTileStyle style = AppListTileStyle.grouped, bool enabled = true, int? reorderIndex, bool reorderEnabled = true, String? semanticLabel, Key? key})
Cria um AppListTileRadio.
const

Properties

enabled bool
Se está habilitado.
final
groupValue → T?
Valor selecionado no grupo.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leading Widget?
Leading (ícone/avatar), opcional.
final
onChanged ValueChanged<T?>?
Callback de seleção.
final
reorderEnabled bool
Se o reordenamento está ativo.
final
reorderIndex int?
Draggable: índice de reordenamento.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
Rótulo de acessibilidade (default: title).
final
style AppListTileStyle
Estilo do container quando avulso.
final
subtitle String?
Subtítulo (muted, opcional).
final
title String
Título (forte).
final
value → T
Valor deste item.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited