AppMenuDivider class final
Uma divisória entre entradas do menu.
- Inheritance
-
- Object
- AppMenuEntry
- AppMenuDivider
Constructors
- AppMenuDivider()
-
Cria um AppMenuDivider.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited