AppPieChartSegment class final

Constructors

AppPieChartSegment({required String label, required double value, Color? color, String? semanticLabel})
const

Properties

color Color?
final
hashCode int
The hash code for this object.
no setterinherited
label String
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
value double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited