AppPopoverController class final

Controla um AppPopover de forma programática (abrir/fechar de fora).

final controller = AppPopoverController();
// ...
AppPopover(controller: controller, trigger: ..., child: ...);
controller.open();

Constructors

AppPopoverController()

Properties

hashCode int
The hash code for this object.
no setterinherited
isOpen bool
Se o popover está aberto.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Fecha o popover.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open() → void
Abre o popover.
toggle() → void
Abre se fechado; fecha se aberto.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited