AppStepData class final

Dados de um passo do AppStepper.

Constructors

AppStepData({required String title, String? subtitle, String? icon})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
icon String?
Icone opcional do passo. Se nulo, exibe o numero do passo.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String?
Subtitulo opcional do passo.
final
title String
Titulo do passo.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited