AppTimeMaskFormatter class final
Máscara de horário HH:mm (ou HH:mm:ss quando showSeconds). Usada pelo
AppTimePickerInput.
- Inheritance
-
- Object
- TextInputFormatter
- AppTimeMaskFormatter
Constructors
- AppTimeMaskFormatter({bool showSeconds = false})
-
Cria um AppTimeMaskFormatter.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showSeconds → bool
-
Se inclui a coluna de segundos (
HH:mm:ss).final
Methods
-
formatEditUpdate(
TextEditingValue oldValue, TextEditingValue newValue) → TextEditingValue -
Called when text is being typed or cut/copy/pasted in the EditableText.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited