AppTooltipSize enum
Tamanho do tooltip: controla o TAMANHO DA FONTE do balão. O padding é constante (médio) nos três.
Values
- small → const AppTooltipSize
-
Fonte compacta (
bodySmall, 12). - medium → const AppTooltipSize
-
Fonte padrão (
bodyMedium, 14). - large → const AppTooltipSize
-
Fonte ampla (
bodyLarge, 16).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AppTooltipSize> - A constant List of the values in this enum, in order of their declaration.