CodeExample class

A usage code sample for a component.

Constructors

CodeExample({required LocalizedText title, required String code, LocalizedText? description})
Creates a CodeExample.
const

Properties

code → String
Code snippet.
final
description → LocalizedText?
Optional description.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → LocalizedText
Example title.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
Serializes to the format consumed by the MCP server.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited