PropMeta class

Metadata for a public prop of a component.

Constructors

PropMeta({required String name, required String type, bool isRequired = false, String? defaultValue, LocalizedText? description, List<String> enumValues = const <String>[]})
Creates a PropMeta.
const

Properties

defaultValue → String?
Default value (as text), if any.
final
description → LocalizedText?
Short description.
final
enumValues → List<String>
Possible values, if it is an enum/union.
final
hashCode → int
The hash code for this object.
no setterinherited
isRequired → bool
Whether it is required.
final
name → String
Prop name.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
Dart type of the prop (e.g. AppButtonColor, String?).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
Serializes to the format consumed by the MCP server.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited