AppMarkdownTableData class final

Estrutura de dados para renderização de tabela.

Constructors

AppMarkdownTableData({required List<String> columnLabels, required List<List<String>> rows})
const

Properties

columnLabels List<String>
Labels do cabeçalho.
final
hashCode int
The hash code for this object.
no setterinherited
rows List<List<String>>
Linhas da tabela.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited