AppSearchableDropdown<T> class
final
Dropdown de seleção única com busca: um campo de filtro no topo do overlay restringe as opções por texto. Reusa o core de dropdown.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- AppSearchableDropdown
Constructors
-
AppSearchableDropdown({required ValueChanged<
T?> onChanged, required List<AppDropdownOption< options, bool enabled = true, String? errorText, bool hasError = false, String? helperText, String? hintText, String? label, Widget? info, String? searchHintText, T? selectedValue, AppStyle? style, AppFieldSize size = AppFieldSize.m, Key? key})T> > -
Cria um AppSearchableDropdown.
const
Properties
- enabled → bool
-
Se está habilitado.
final
- errorText → String?
-
Texto de erro.
final
- hasError → bool
-
Se está em erro.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- helperText → String?
-
Texto auxiliar.
final
- hintText → String?
-
Placeholder do trigger.
final
- info → Widget?
-
Conteúdo livre de um popover de informação ao lado do label.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String?
-
Label acima do campo.
final
-
onChanged
→ ValueChanged<
T?> -
Callback ao mudar o valor.
final
-
options
→ List<
AppDropdownOption< T> > -
Opções disponíveis.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchHintText → String?
-
Placeholder do campo de busca.
final
- selectedValue → T?
-
Valor selecionado.
final
- size → AppFieldSize
-
Tamanho do campo (altura fixa + métricas). Default AppFieldSize.m.
final
- style → AppStyle?
-
Eixo global AppStyle do trigger.
nullsegue o global do tema.final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< AppSearchableDropdown< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited