AppShimmerLoading class final
The App Shimmer Loading widget — placeholder com brilho animado.
Sob reduce-motion renderiza o box base estático (sem o brilho), respeitando a preferência de acessibilidade.
Example:
AppShimmerLoading(height: AppSizes.s16, width: AppSizes.s16)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- AppShimmerLoading
Constructors
- AppShimmerLoading({required double height, Color? color, BorderRadius? borderRadius, Color? highlightColor, EdgeInsets? margin, double width = double.infinity, Key? key})
-
const
Properties
- borderRadius → BorderRadius?
-
The border radius of the shimmer. Quando
null, usa o radius médio do tema (modo redondo, proporcional ao tamanho).final - color → Color?
-
The base color of the shimmer. Defaults to
onSurface(barrier).final - hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
The height of the shimmer.
final
- highlightColor → Color?
-
The highlight color of the shimmer. Defaults to
surface(disabled).final - key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- margin → EdgeInsets?
-
The margin of the shimmer. Defaults to EdgeInsets.zero.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → double
-
The width of the shimmer. Defaults to double.infinity.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited