AppTabViewItem class final

Dados de cada aba do AppTabView.

Constructors

AppTabViewItem({required WidgetBuilder builder, required String label})
const

Properties

builder WidgetBuilder
Construtor do conteúdo da aba.
final
hashCode int
The hash code for this object.
no setterinherited
label String
Texto exibido no cabeçalho da aba.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited