FlocksStatesController class
Controlador de estados de interação do Flocks.
Fino wrapper sobre WidgetStatesController (camada widgets, sem
Material/Cupertino) com getters de conveniência. Usado internamente por
FlocksInteraction e exposto para componentes que precisem dirigir os
estados manualmente.
- Inheritance
-
- Object
- ChangeNotifier
- ValueNotifier<
Set< WidgetState> > - WidgetStatesController
- FlocksStatesController
Constructors
-
FlocksStatesController([Set<
WidgetState> ? value]) - Cria o controlador, opcionalmente com um conjunto inicial de estados.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- isDisabled → bool
-
Se WidgetState.disabled está presente.
no setter
- isFocused → bool
-
Se WidgetState.focused está presente.
no setter
- isHovered → bool
-
Se WidgetState.hovered está presente.
no setter
- isPressed → bool
-
Se WidgetState.pressed está presente.
no setter
- isSelected → bool
-
Se WidgetState.selected está presente.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
value
↔ Set<
WidgetState> -
The current value stored in this notifier.
getter/setter pairinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
WidgetState state, bool add) → void -
Adds
stateto value ifaddis true, and removes it otherwise, and notifies listeners if value has changed.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited